@@ -5,7 +5,7 @@
 
 ;; Author: Pierre Neidhardt <mail@ambrevar.xyz>
 ;; URL: https://github.com/emacs-helm/helm-system-packages
-;; Version: 1.10.1
+;; Version: 1.10.2
 ;; Package-Requires: ((emacs "24.4") (helm "2.8.6"))
 ;; Keywords: helm, packages
 
@@ -28,7 +28,6 @@
 ;; TODO: Fix missing newline when printing virtual packages.
 
 ;;; Code:
-(require 'helm)
 (require 'helm-system-packages)
 
 ;; Shut up byte compiler
@@ -41,7 +40,7 @@
 ** Options
 
 - `helm-system-packages-pacman-confirm-p'
-- `helm-system-packages-pacman-sync-threshold'
+- `helm-system-packages-pacman-synchronize-threshold'
 - `helm-system-packages-pacman-auto-clean-cache'
 
 ** Commands
@@ -179,7 +178,7 @@ If nil, then use `helm-system-packages-column-width'."
       ;; Local packages are necessarily either explicitly installed or a required dependency or an orphan.
       (push 'helm-system-packages-locals (cdr (assoc p display-list))))
     (dolist (p groups)
-      (push (cons p '(helm-system-pacman-groups)) display-list))
+      (push (cons p '(helm-system-packages-groups)) display-list))
     (helm-system-packages-pacman-cache display-list locals groups)))
 
 (defcustom helm-system-packages-pacman-synchronize-threshold 86400
